:mod:`euphorie.client.browser.module`
=====================================

.. automodule:: euphorie.client.browser.module
   :members:

.. autoclass:: IdentificationView
   :members:

.. autoclass:: ActionPlanView
   :members:

